==> snortsms-0.14.9.tbz: www/snortsms/fbx_Settings.php <==
<?php
/*
Fusebox Software License
Version 1.0

Copyright (c) 2001-2005 The Fusebox Corporation. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form or otherwise encrypted form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment:

"This product includes software developed by the Fusebox Corporation (http://www.fusebox.org/)."

Alternately, this acknowledgment may appear in the software itself, if and wherever such third-party acknowledgments normally appear.

4. The names "Fusebox" and "Fusebox Corporation" must not be used to endorse or promote products derived from this software without prior written (non-electronic) permission. For written permission, please contact fusebox@fusebox.org.

5. Products derived from this software may not be called "Fusebox", nor may "Fusebox" appear in their name, without prior written (non-electronic) permission of the Fusebox Corporation. For written permission, please contact fusebox@fusebox.org.

If one or more of the above conditions are violated, then this license is immediately revoked and can be re-instated only upon prior written authorization of the Fusebox Corporation.

THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FUSEBOX CORPORATION OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--------------------------------------------------------------------------------

This software consists of voluntary contributions made by many individuals on behalf of the Fusebox Corporation. For more information on Fusebox, please see <http://www.fusebox.org/>.
*/

/*
<fusedoc fuse="fbx_Settings.php">
	<responsibilities>
		I set up the enviroment settings for this circuit. If this settings file is being inherited, then you can set a variable outright to override a value set in a parent circuit or use if(!isset(...)) to accept a value set by a parent circuit
	</responsibilities>	
</fusedoc>
*/

//In case no fuseaction was given, I'll set up one to use by default.
if(!isset($attributes["fuseaction"])){ $attributes["fuseaction"] = "home.main"; }

//useful constants
if(!isset($GLOBALS["self"])){ $GLOBALS["self"] = "index.php"; }
$XFA = array();

//default values for layout files
$Fusebox["layoutDir"] = "";
$Fusebox["layoutFile"] = "fbx_DefaultLayout.php";

//should fusebox silently suppress its own error messages? default is FALSE
$Fusebox["suppressErrors"] = false;

if($Fusebox["isHomeCircuit"]) {
//put settings here that you want to execute only when this is the application's home circuit (for example: session_start(); )

} else {
//put settings here that you want to execute only when this is not an application's home circuit


}
//Put settings out here that should run regardless of whether this is the home app or not
include_once("lib/func_Log.php");

/* ############## VERSION ############## */
$GBL['VERSION'] = "0.14.9 - beta";
/* ################################## */

/*** Initialize Global settings ***/
list($GBL['DOC_ROOT'],$crap) = explode('index.php',$_SERVER['SCRIPT_FILENAME'],2);
$GBL['conf_file'] = $GBL['DOC_ROOT'] . "/conf/conf.php";
if ( file_exists( $GBL['conf_file'] ) )
	{
	include_once("conf/conf.php");
	$GBL['trashcan'] = $GBL['tmpdir'] . "/snortsms.recycle.bin";
	$GBL['tmpdir'] .= "/.snortsms";	
	}
else
	{
	/* Load default vaules */
	include_once("conf/act_init_vars.php");
	}

	
	
/*** Check if log facility is enabled and file exists ***/
if($GBL['log_file'] != "")
	{
	if(!file_exists($GBL['log_file']))
		{
		if(!touch($GBL['log_file']))
			{
			?><P> Error: Cannot create log file. Please check you Global Settings. Verify the file exists, and is read/writtable by web server.</P><?
			}
		}	
	}
	
	

/*** Include PEAR DB wrapper functions ***/
require_once( "DB.php" );





/*** Open Persistant Database Conection ***/
$GBL["dbdsn"] = $GBL["dbtype"] . "://" . $GBL["dbuser"] . ":" . $GBL["dbpasswd"] . "@" . $GBL["dbhost"] . "/" . $GBL["dbname"];	// DSN String
$db = DB::connect($GBL["dbdsn"],true);
if (DB::isError($db))
	{
	$error = $db->getMessage();
	?>
	<CENTER>
	<BR>
	<table bgcolor="Red"><tr><td>
	<table bgcolor ="White">
	<tr><td>
	<h3 style="color:Red;">Error: Cannot connect to the SnortSMS database.</h3>
	<P><B>Please verify the DB <i>name, type, IP, UserID, and Password</i> are correct in <a href="index.php?fuseaction=conf.main">'Global Setting'</a> menu, and that the database exists.</B></P>
	<P>Error code: <?=$error?></P>
	</td></tr>
	</table>
	</td></tr></table>
	</CENTER>
	<?
	LogEvent("Error: cannot connect to SnortSMS database: $error");
	}





/*****************************************
*** Application Session Management ***
******************************************/
//$application = session_name("SNORTSMS");
/*** Start new session or carry existing session. ***/

session_start();



/*** Init new session variables. ***/
if ($_SESSION['rollcount'] <= 0)
   	{
	/*** This is a new session, set default values ***/
	$_SESSION['rollcount'] = 1;
	$_SESSION['auth'] = 0;
	$_SESSION['sensorid'] = NULL;
	$_SESSION['st'] = "";
	$_SESSION['et'] = "";
	$_SESSION['window'] = "";
	}
else
	{
	/*** Session already established ***/
	$_SESSION['rollcount']++;
	}
/*****************************************/





function Stop($msg)
	{
	Global $Fusebox;
	/*
	print"<PRE>\n";
	print_r($_SERVER);
	print_r($Fusebox);
	print"<PRE>\n";
	*/
	$msg = "Fatal Error: " . $msg;
	LogEvent($msg);
	die($msg);
	}


?>

==> snortsms-1.0.0.tbz: www/snortsms/fbx_Settings.php <==
<?php
/*
Fusebox Software License
Version 1.0

Copyright (c) 2001-2005 The Fusebox Corporation. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form or otherwise encrypted form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment:

"This product includes software developed by the Fusebox Corporation (http://www.fusebox.org/)."

Alternately, this acknowledgment may appear in the software itself, if and wherever such third-party acknowledgments normally appear.

4. The names "Fusebox" and "Fusebox Corporation" must not be used to endorse or promote products derived from this software without prior written (non-electronic) permission. For written permission, please contact fusebox@fusebox.org.

5. Products derived from this software may not be called "Fusebox", nor may "Fusebox" appear in their name, without prior written (non-electronic) permission of the Fusebox Corporation. For written permission, please contact fusebox@fusebox.org.

If one or more of the above conditions are violated, then this license is immediately revoked and can be re-instated only upon prior written authorization of the Fusebox Corporation.

THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FUSEBOX CORPORATION OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--------------------------------------------------------------------------------

This software consists of voluntary contributions made by many individuals on behalf of the Fusebox Corporation. For more information on Fusebox, please see <http://www.fusebox.org/>.
*/

/*
<fusedoc fuse="fbx_Settings.php">
	<responsibilities>
		I set up the enviroment settings for this circuit. If this settings file is being inherited, then you can set a variable outright to override a value set in a parent circuit or use if(!isset(...)) to accept a value set by a parent circuit
	</responsibilities>	
</fusedoc>
*/

//In case no fuseaction was given, I'll set up one to use by default.
if(!isset($attributes["fuseaction"])){ $attributes["fuseaction"] = "home.main"; }

//useful constants
if(!isset($GLOBALS["self"])){ $GLOBALS["self"] = "index.php"; }
$XFA = array();

//default values for layout files
$Fusebox["layoutDir"] = "";
$Fusebox["layoutFile"] = "fbx_DefaultLayout.php";

//should fusebox silently suppress its own error messages? default is FALSE
$Fusebox["suppressErrors"] = false;

if($Fusebox["isHomeCircuit"]) {
//put settings here that you want to execute only when this is the application's home circuit (for example: session_start(); )

} else {
//put settings here that you want to execute only when this is not an application's home circuit


}
//Put settings out here that should run regardless of whether this is the home app or not
include_once("lib/func_Log.php");

/* ############## VERSION ############## */
$GBL['VERSION'] = "1.0.0";
/* ################################## */

/*** Initialize Global settings ***/
list($GBL['DOC_ROOT'],$crap) = explode('index.php',$_SERVER['SCRIPT_FILENAME'],2);
//print "<P>-".$GBL['DOC_ROOT']."</p>";
$GBL['conf_file'] = $GBL['DOC_ROOT'] . "/conf/conf.php";
if ( file_exists( $GBL['conf_file'] ) )
	{
	include_once("conf/conf.php");
	$GBL['trashcan'] = $GBL['tmpdir'] . "/snortsms.recycle.bin";
	$GBL['tmpdir'] .= "/.snortsms";	
	}
else
	{
	/* Load default vaules */
	include_once("conf/act_init_vars.php");
	}

	
	
/*** Check if log facility is enabled and file exists ***/
if($GBL['log_file'] != "")
	{
	if(!file_exists($GBL['log_file']))
		{
		if(!touch($GBL['log_file']))
			{
			?><P> Error: Cannot create log file. Please check you Global Settings. Verify the file exists, and is read/writtable by web server.</P><?
			}
		}	
	}
	
	

/*** Include PEAR DB wrapper functions ***/
require_once( "DB.php" );





/*** Open Persistant Database Conection ***/
$GBL["dbdsn"] = $GBL["dbtype"] . "://" . $GBL["dbuser"] . ":" . $GBL["dbpasswd"] . "@" . $GBL["dbhost"] . "/" . $GBL["dbname"];	// DSN String
$db = DB::connect($GBL["dbdsn"],true);
if (DB::isError($db))
	{
	$error = $db->getMessage();
	?>
	<CENTER>
	<BR>
	<table bgcolor="Red"><tr><td>
	<table bgcolor ="White">
	<tr><td>
	<h3 style="color:Red;">Error: Cannot connect to the SnortSMS database.</h3>
	<P><B>Please verify the DB <i>name, type, IP, UserID, and Password</i> are correct in <a href="index.php?fuseaction=conf.main">'Global Setting'</a> menu, and that the database exists.</B></P>
	<P>Error code: <?=$error?></P>
	</td></tr>
	</table>
	</td></tr></table>
	</CENTER>
	<?
	LogEvent("Error: cannot connect to SnortSMS database: $error");
	}





/*****************************************
*** Application Session Management ***
******************************************/
//$application = session_name("SNORTSMS");
/*** Start new session or carry existing session. ***/

session_start();



/*** Init new session variables. ***/
if ($_SESSION['rollcount'] <= 0)
   	{
	/*** This is a new session, set default values ***/
	$_SESSION['rollcount'] = 1;
	$_SESSION['auth'] = 0;
	$_SESSION['sensorid'] = NULL;
	$_SESSION['st'] = "";
	$_SESSION['et'] = "";
	$_SESSION['window'] = "";
	}
else
	{
	/*** Session already established ***/
	$_SESSION['rollcount']++;
	}
/*****************************************/





function Stop($msg)
	{
	Global $Fusebox;
	/*
	print"<PRE>\n";
	print_r($_SERVER);
	print_r($Fusebox);
	print"<PRE>\n";
	*/
	$msg = "Fatal Error: " . $msg;
	LogEvent($msg);
	die($msg);
	}


?>
